#   Copyright (C) 2002, Peter Roozemaal.
#
# GnuCoMo/CoConf is free software; you may redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.  See the file COPYING.

"The widget definitions that build a form"

import string
import os
import Tkinter
import tkMessageBox
import ScrolledText
from textbase import txt

_id = "$Id: cotkwidget.py,v 1.1 2002-11-19 19:21:18 arjen Exp $"

_helpwins = {}

class HelpWin(Tkinter.Toplevel):
    def __init__(self, item, text):
        global _helpwins
        Tkinter.Toplevel.__init__(self)
        self.title(txt("helpon","help on")+" "+item)
        _helpwins[item] = self
        self.name = item
        self.bind("<Destroy>", self.cleanup)
        self.textwin = ScrolledText.ScrolledText(self, takefocus=0, wrap="word")
        self.textwin.pack(side="top")
        self.textwin.insert("1.0", text)
        self.textwin["state"] = "disabled"
        self.button = Tkinter.Button(self, text=txt("thanks", "Thank You"),
                                     relief="groove", borderwidth=4,
                                     command=self.destroy)
        self.button.pack(side="bottom")
    def cleanup(self, event):
        if _helpwins.has_key(self.name):
            del _helpwins[self.name]

class _BaseWidget:
    widgetname = ""
    curhelp = ""
    defhelp = ""
    help = {}

    def cleanup(self):
        self.destroy()

    def readDom(self, dom):
        self.widgetname = dom.getAttribute("name")
        for i in self.translate:
            att = dom.getAttribute(i)
            setattr(self, "cur"+i, att)
            setattr(self, "def"+i, att)
            setattr(self, i, {})
            getattr(self, i)[dom.getAttribute("language")] = att
        el = dom.firstChild
        while el != None:
            if el.nodeType == el.ELEMENT_NODE:
                if el.tagName == "help":
                    self.readHelp(el)
                elif el.tagName == "translate":
                    self.readTrans(el)
                else:
                    print self.widgetname, "bad element:", el.tagName
            #else:
                #print self.widgetname, "bad xml node:", el.nodeName
            el = el.nextSibling

    def readHelp(self, dom):
        lang = dom.getAttribute("language")
        text = ""
        el = dom.firstChild
        while el != None:
            if el.nodeType == el.TEXT_NODE:
                text = text + el.data
            el = el.nextSibling
        text = string.join(string.split(text))
        if self.curhelp == "":
            self.curhelp = text
        if self.defhelp == "":
            self.defhelp = text
        self.help[lang] = text

    def readTrans(self, dom):
        pass

    def provide_help(self):
        if _helpwins.has_key(self.widgetname):
            _helpwins[self.widgetname].lift()
        elif self.curhelp:
            HelpWin(self.widgetname, self.curhelp)
        else:
            tkMessageBox.showinfo(title=txt("sorry", "Sorry"),
                                  message=txt("nohelp", "The creator of the form didn't provide a help message."))

    def value_dom(self, document, parent, flags):
        #TODO: check flags
        node = document.createElement("variable")
        node.setAttribute("name", self.widgetname)
        #the next line isn't OO clean
        node.setAttribute("value", str(self.variable.get()))
        parent.appendChild(node)

class _ComposedWidget(_BaseWidget):
    def readDom(self, dom):
        self.widgetname = dom.getAttribute("name")
        for i in self.translate:
            att = dom.getAttribute(i)
            setattr(self, "cur"+i, att)
            setattr(self, "def"+i, att)
            setattr(self, i, {})
            getattr(self, i)[dom.getAttribute("language")] = att
        el = dom.firstChild
        while el != None:
            if el.nodeType == el.ELEMENT_NODE:
                if el.tagName == "help":
                    self.readHelp(el)
                elif el.tagName == "translate":
                    self.readTrans(el)
                elif _subwidgets.has_key(el.tagName):
                    w = _subwidgets[el.tagName](self, el)
                    self.add_widget(w)
                else:
                    print self.widgetname, "bad element:", el.tagName
            #else:
                #print self.widgetname, "bad xml node:", el.nodeName
            el = el.nextSibling

class FormWin(Tkinter.Frame, _ComposedWidget):
    translate = ( "title", )
    def __init__(self, master, dom):
        Tkinter.Frame.__init__(self, master)
        self.wlist = []
        self.readDom(dom)
    def cleanup(self):
        for sub in self.wlist:
            sub.cleanup()
        self.destroy()
    def add_widget(self, wid):
        self.wlist.append(wid)
        wid.pack(side="top", fill="x")
    def value_dom(self, document, parent, flags):
        if flags:
            node = document.createElement("export")
        else:
            node = document.createElement("save")
        node.setAttribute("form", self.widgetname)
        parent.appendChild(node)
        for sub in self.wlist:
            sub.value_dom(document, node, flags)

class Group(Tkinter.Frame, _ComposedWidget):
    translate = ()
    def __init__(self, master, dom):
        Tkinter.Frame.__init__(self, master)
        self.wlist = []
        self.filler = Tkinter.Frame(self, width="7m")
        self.filler.pack(side="left", fill="y")
        self.inner = Tkinter.Frame(self)
        self.inner.pack(side="right", fill="both", expand=1)
        self.readDom(dom)
    def cleanup(self):
        for sub in self.wlist:
            sub.cleanup()
        self.destroy()
    def add_widget(self, wid):
        self.wlist.append(wid)
        wid.pack(side="top", fill="x", in_=self.inner)
    def value_dom(self, document, parent, flags):
        #TODO: check flags
        node = document.createElement("group")
        node.setAttribute("name", self.widgetname)
        parent.appendChild(node)
        for sub in self.wlist:
            sub.value_dom(document, node, flags)

class Boolean(Tkinter.Frame, _BaseWidget):
    translate = ( "label", )
    def __init__(self, master, dom):
        Tkinter.Frame.__init__(self, master)
        self.readDom(dom)
        self.button = Tkinter.Checkbutton(self, text=self.curlabel)
        self.button.pack(side="left")
        self.variable = Tkinter.BooleanVar()
        self.button["variable"] = self.variable
        if os.name == "posix":
            self.button["selectcolor"] = "green"
        self.helpbutton = Tkinter.Button(self, text=txt("lhelp", "?"),
                                         command=self.provide_help)
        self.helpbutton.pack(side="right")

class String(Tkinter.Frame, _BaseWidget):
    translate = ( "label", )
    def __init__(self, master, dom):
        Tkinter.Frame.__init__(self, master)
        self.readDom(dom)
        self.label = Tkinter.Label(self, text=self.curlabel)
        self.label.pack(side="left")
        self.variable = Tkinter.StringVar()
        self.veld = Tkinter.Entry(self, textvariable=self.variable)
        self.helpbutton = Tkinter.Button(self, text=txt("lhelp", "?"),
                                         command=self.provide_help)
        self.helpbutton.pack(side="right")
        self.veld.pack(side="right", fill="x")

class Ruler(Tkinter.Frame):
    def __init__(self, master, dom):
        Tkinter.Frame.__init__(self, master, relief="sunken", height=4,
                               borderwidth=2)
    def value_dom(self, document, parent, flags):
        pass
    def cleanup(self):
        self.destroy()

_subwidgets = {
    "boolean" : Boolean,
    "group" : Group,
    "ruler" : Ruler,
    "string" : String
}
