
/**************************************************************************
**  (c) Copyright 2002, Andromeda Technology & Automation
** This is free software; you can redistribute it and/or modify it under the
** terms of the GNU General Public License, see the file COPYING.
***************************************************************************
** MODULE INFORMATION *
***********************
**      FILE NAME      : error_cooker.cpp
**      SYSTEM NAME    : 
**      VERSION NUMBER : $Revision: 1.3 $
**
**  DESCRIPTION      :  Cooks Apache http daemon error log lines
**
**  EXPORTED OBJECTS : 
**  LOCAL    OBJECTS : 
**  MODULES  USED    :
***************************************************************************
**  ADMINISTRATIVE INFORMATION *
********************************
**      ORIGINAL AUTHOR : Arjen Baart - arjen@andromeda.nl
**      CREATION DATE   : Aug 11, 2003
**      LAST UPDATE     : Aug 11, 2003
**      MODIFICATIONS   : 
**************************************************************************/

/*****************************
   $Log: error_cooker.cpp,v $
   Revision 1.3  2007-12-10 16:13:16  arjen
   Accept [info] as a valid httpd error line.

   Revision 1.2  2003/12/22 10:22:22  arjen
   Accept a wider range of input patterns

   Revision 1.1  2003/08/11 16:56:16  arjen
   Different kinds of log files are parsed by a collection of objects
   of different classes, derived from the base class line_cooker
   Depending on the message content or the message_type element in
   XML, one of these objects is selected.

   Logrunner is integrated with gcm_input. Although its functionality
   is still limited, a connection between logrunner and gcm_input
   is beginning to form.

*****************************/

/* static const char *RCSID = "$Id: error_cooker.cpp,v 1.3 2007-12-10 16:13:16 arjen Exp $"; */

#include <ctype.h>

#include "error_cooker.h"

static const String unix_date_re("[[:alpha:]]{3} [[:alpha:]]{3} [ 123][0-9] [0-9]{2}:[0-9]{2}:[0-9]{2} [0-9]{4}");
static const regex re_errorlog("^\\[" + unix_date_re + "\\] \\[(error|notice|warn|info)\\] .+");

bool error_cooker::check_pattern(String logline)
{
   return logline == re_errorlog;
}

bool error_cooker::cook_this(String logline, UTC arrival)
{
   if (check_pattern(logline))
   {
      String datestring = logline(regex("\\[.+\\]"));

      datestring <<= 1;
      datestring >>= 1;

      date   log_date = datestring;
      hour   log_time = datestring;

      log_date = datestring;
      log_time = datestring;

      ts = UTC(log_date, log_time);

      hn  = "";
      srv = "httpd";

      return true;
   }
   else
   {
      return false;
   }
}


