
/**************************************************************************
**  (c) Copyright 2002, Andromeda Technology & Automation
** This is free software; you can redistribute it and/or modify it under the
** terms of the GNU General Public License, see the file COPYING.
***************************************************************************
** MODULE INFORMATION *
***********************
**      FILE NAME      : line_cooker.h
**      SYSTEM NAME    : 
**      VERSION NUMBER : $Revision: 1.1 $
**
**  DESCRIPTION      :  The line_cooker abstract base class.
**                      Defines the interface for a collection of derived
**                      classes the parse different kinds of logs.
**
**  EXPORTED OBJECTS : 
**  LOCAL    OBJECTS : 
**  MODULES  USED    :
***************************************************************************
**  ADMINISTRATIVE INFORMATION *
********************************
**      ORIGINAL AUTHOR : Arjen Baart - arjen@andromeda.nl
**      CREATION DATE   : Aug 06, 2003
**      LAST UPDATE     : Aug 06, 2003
**      MODIFICATIONS   : 
**************************************************************************/

/*****************************
   $Log: line_cooker.h,v $
   Revision 1.1  2003-08-11 16:56:16  arjen
   Different kinds of log files are parsed by a collection of objects
   of different classes, derived from the base class line_cooker
   Depending on the message content or the message_type element in
   XML, one of these objects is selected.

   Logrunner is integrated with gcm_input. Although its functionality
   is still limited, a connection between logrunner and gcm_input
   is beginning to form.

*****************************/

/* static const char *RCSID = "$Id: line_cooker.h,v 1.1 2003-08-11 16:56:16 arjen Exp $"; */

#ifndef LINE_COOKER_H
#define LINE_COOKER_H

#include <AXE/String.h>
#include <AXE/date.h>

/*
///////////////////////////////////////////////////////////////////////////
//  NAME           : line_cooker
//  BASECLASS      : 
//  MEMBERS        :
//  OPERATORS      :
//  METHODS        : 
//
//  DESCRIPTION    : 
//
//  RELATIONS      :
//  SEE ALSO       :
//  LAST MODIFIED  : Aug 06, 2003
///////////////////////////////////////////////////////////////////////////
*/

class line_cooker
{

protected:

   UTC    ts;     //    the timestamp.
   String hn;     //    the hostname
   String srv;    //    the service

public:

   line_cooker()
   {
   }

   virtual bool check_pattern(String logline) = 0;
   virtual bool cook_this(String logline, UTC arrival) = 0;

   virtual String message_type() = 0;

   UTC timestamp()
   {
      return ts;
   }

   String hostname()
   {
      return hn;
   }

   String service()
   {
      return srv;
   }
};

#endif // LINE_COOKER_H
