
/**************************************************************************
**  (c) Copyright 2003, Andromeda Technology & Automation
** This is free software; you can redistribute it and/or modify it under the
** terms of the GNU General Public License, see the file COPYING.
***************************************************************************
** MODULE INFORMATION *
***********************
**      FILE NAME      : log_filter.cpp
**      SYSTEM NAME    : 
**      VERSION NUMBER : $Revision: 1.1 $
**
**  DESCRIPTION      : Implementation of the log_filter class 
**
**  EXPORTED OBJECTS : 
**  LOCAL    OBJECTS : 
**  MODULES  USED    :
***************************************************************************
**  ADMINISTRATIVE INFORMATION *
********************************
**      ORIGINAL AUTHOR : Arjen Baart - arjen@andromeda.nl
**      CREATION DATE   : Nov 26, 2003
**      LAST UPDATE     : Nov 26, 2003
**      MODIFICATIONS   : 
**************************************************************************/

/*****************************
   $Log: log_filter.cpp,v $
   Revision 1.1  2003-12-04 10:38:09  arjen
   Major redesign. All input is handled through XML. Raw input data is first
   transformed into an XML document for further processing.
   A collection of polymorphic classes handle the transformation of various
   input formats into XML.
   Classifying input data is done with a finite improbability calculation.

*****************************/

/* static const char *RCSID = "$Id: log_filter.cpp,v 1.1 2003-12-04 10:38:09 arjen Exp $"; */

#include "log_filter.h"

extern String XML_Entities(String s);

/*=========================================================================
**  NAME           : constructXML
**  SYNOPSIS       : int constructXML(message_buffer &in, strstream &xml)
**  PARAMETERS     : 
**  RETURN VALUE   : None
**
**  DESCRIPTION    : Create the body for a Gnucomo XML document. Each line
**                   of input from the log file is put in a <raw> XML element.
**
**  VARS USED      :
**  VARS CHANGED   :
**  FUNCTIONS USED :
**  SEE ALSO       :
**  LAST MODIFIED  : Nov 26, 2003
**=========================================================================
*/

void log_filter::construct_XML(message_buffer &in, std::strstream &xml)
{
   String line;

   scan_email_header(in);
   construct_header(xml);

   xml << "  <gcmt:data>\n";
   xml << "    <gcmt:log>\n";
   while (in >> line)
   {
      xml << "    <gcmt:raw>" << XML_Entities(line) << "</gcmt:raw>\n";
   }
   xml << "    </gcmt:log>\n";
   xml << "  </gcmt:data>\n";
   xml << "</gcmt:message>\n";
}

