
/**************************************************************************
**  (c) Copyright 2002, Andromeda Technology & Automation
** This is free software; you can redistribute it and/or modify it under the
** terms of the GNU General Public License, see the file COPYING.
***************************************************************************
** MODULE INFORMATION *
***********************
**      FILE NAME      : message_buffer.h
**      SYSTEM NAME    : 
**      VERSION NUMBER : $Revision: 1.1 $
**
**  DESCRIPTION      :  Classes to for buffering the input stream
**
**  EXPORTED OBJECTS : 
**  LOCAL    OBJECTS : 
**  MODULES  USED    :
***************************************************************************
**  ADMINISTRATIVE INFORMATION *
********************************
**      ORIGINAL AUTHOR : Arjen Baart - arjen@andromeda.nl
**      CREATION DATE   : Sep 16, 2002
**      LAST UPDATE     : Aug 06, 2003
**      MODIFICATIONS   : 
**************************************************************************/

/*****************************
   $Log: message_buffer.h,v $
   Revision 1.1  2003-12-04 10:38:09  arjen
   Major redesign. All input is handled through XML. Raw input data is first
   transformed into an XML document for further processing.
   A collection of polymorphic classes handle the transformation of various
   input formats into XML.
   Classifying input data is done with a finite improbability calculation.

*****************************/

/* static const char *RCSID = "$Id: message_buffer.h,v 1.1 2003-12-04 10:38:09 arjen Exp $"; */

#include <iostream>
#include <list>
#include <AXE/String.h>


/*
///////////////////////////////////////////////////////////////////////////
//  NAME           : message_buffer
//  BASECLASS      : 
//  MEMBERS        :
//  OPERATORS      :
//  METHODS        : from()
//                   rewind()
//
//  DESCRIPTION    : 
//
//  RELATIONS      :
//  SEE ALSO       :
//  LAST MODIFIED  : Nov 04, 2002
///////////////////////////////////////////////////////////////////////////
*/

class message_buffer
{
   std::istream       *input;
   std::list<String>  buffer;

   std::list<String>::iterator   next_line;

public:

   message_buffer()
   {
      input = 0;
      next_line = buffer.begin();
   }

   message_buffer(std::istream *in)
   {
      input = in;
      next_line = buffer.begin();
   }

   void from(std::istream *in)
   {
      input = in;
   }

   friend bool operator >> (message_buffer &, String &);

   void rewind()
   {
      next_line = buffer.begin();
   }

   void operator ++()
   {
      if (next_line != buffer.end())
      {
         next_line++;
      }
   }

   void operator --()
   {
      if (next_line != buffer.begin())
      {
         next_line--;
      }
   }
};

